@@ -1,22 +1,9 @@
 /*
-    Copyright (c) 2002-2004 Marc Mutz <mutz@kde.org>
-    Copyright (c) 2007 Tom Albers <tomalbers@kde.nl>
-    Copyright (c) 2009 Thomas McGuire <mcguire@kde.org>
+    SPDX-FileCopyrightText: 2002-2004 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2007 Tom Albers <tomalbers@kde.nl>
+    SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "signature.h"
@@ -28,7 +15,6 @@
 #include <KProcess>
 
 #include <QSharedPointer>
-#include <QImage>
 
 #include <assert.h>
 #include <QDir>
@@ -64,7 +50,7 @@ public:
     Signature::Type type = Signature::Disabled;
     bool enabled = false;
     bool inlinedHtml = false;
-    Signature * const q = nullptr;
+    Signature *const q;
 };
 
 static bool isCursorAtEndOfLine(const QTextCursor &cursor)
@@ -165,7 +151,7 @@ static QStringList findImageNames(const QString &htmlCode)
     // To complicated for us, so cheat and let a text edit do the hard work
     KPIMTextEdit::RichTextComposer edit;
     edit.setHtml(htmlCode);
-    const QList<KPIMTextEdit::ImageWithNamePtr> images = edit.composerControler()->composerImages()->imagesWithName();
+    const KPIMTextEdit::ImageWithNameList images = edit.composerControler()->composerImages()->imagesWithName();
     ret.reserve(images.count());
     for (const KPIMTextEdit::ImageWithNamePtr &image : images) {
         ret << image->name;
