@@ -1,20 +1,9 @@
 /*  -*- c++ -*-
-    Copyright 2008 Thomas McGuire <Thomas.McGuire@gmx.net>
-    Copyright 2008 Edwin Schepers <yez@familieschepers.nl>
-    Copyright 2004 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2008 Thomas McGuire <Thomas.McGuire@gmx.net>
+    SPDX-FileCopyrightText: 2008 Edwin Schepers <yez@familieschepers.nl>
+    SPDX-FileCopyrightText: 2004 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "signatureconfigurator.h"
@@ -66,7 +55,7 @@ public:
     void init();
     // Returns the current text of the textedit as HTML code, but strips
     // unnecessary tags Qt inserts
-    QString asCleanedHTML() const;
+    Q_REQUIRED_RESULT QString asCleanedHTML() const;
 
     QString imageLocation;
     SignatureConfigurator *q;
@@ -107,7 +96,7 @@ QString SignatureConfigurator::Private::asCleanedHTML() const
 
 void SignatureConfigurator::Private::init()
 {
-    QVBoxLayout *vlay = new QVBoxLayout(q);
+    auto *vlay = new QVBoxLayout(q);
     vlay->setObjectName(QStringLiteral("main layout"));
 
     // "enable signature" checkbox:
@@ -118,7 +107,7 @@ void SignatureConfigurator::Private::init()
     vlay->addWidget(mEnableCheck);
 
     // "obtain signature text from" combo and label:
-    QHBoxLayout *hlay = new QHBoxLayout(); // inherits spacing
+    auto *hlay = new QHBoxLayout(); // inherits spacing
     vlay->addLayout(hlay);
     mSourceCombo = new QComboBox(q);
     mSourceCombo->setEditable(false);
@@ -139,7 +128,7 @@ void SignatureConfigurator::Private::init()
     hlay->addWidget(mSourceCombo, 1);
 
     // widget stack that is controlled by the source combo:
-    QStackedWidget *widgetStack = new QStackedWidget(q);
+    auto *widgetStack = new QStackedWidget(q);
     widgetStack->setEnabled(false);   // since !mEnableCheck->isChecked()
     vlay->addWidget(widgetStack, 1);
     q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
@@ -156,7 +145,7 @@ void SignatureConfigurator::Private::init()
     // page 0: input field for direct entering:
     QWidget *page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
-    QVBoxLayout *page_vlay = new QVBoxLayout(page);
+    auto *page_vlay = new QVBoxLayout(page);
     page_vlay->setContentsMargins(0, 0, 0, 0);
 
 #ifndef QT_NO_TOOLBAR
@@ -171,7 +160,7 @@ void SignatureConfigurator::Private::init()
 
     mTextEdit = new KPIMTextEdit::RichTextComposer(q);
 
-    KPIMTextEdit::RichTextEditorWidget *richTextEditorwidget = new KPIMTextEdit::RichTextEditorWidget(mTextEdit, q);
+    auto *richTextEditorwidget = new KPIMTextEdit::RichTextEditorWidget(mTextEdit, q);
     page_vlay->addWidget(richTextEditorwidget, 2);
     mTextEdit->setWhatsThis(i18n("Use this field to enter an arbitrary static signature."));
 
